package com.persagy.account.controller;

import java.util.List;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.google.common.collect.Lists;
import com.persagy.account.pojo.dto.SaasAccountRole;
import com.persagy.account.pojo.vo.auth.SaasAccountRoleBatchVO;
import com.persagy.account.pojo.vo.auth.SaasAccountRoleCreateVO;
import com.persagy.account.pojo.vo.auth.SaasAccountRoleQueryVO;
import com.persagy.account.service.ISaasAccountRoleService;
import com.persagy.common.utils.ResponseResult;
import com.persagy.common.utils.ResponseResultUtil;

import cn.hutool.core.collection.CollectionUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 账号-角色关联信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */

@Api(tags = "账号-角色关联信息")
@RestController
@RequestMapping(value = "/accountRole", method = RequestMethod.POST)
public class SaasAccountRoleController {

	@Autowired
    private ISaasAccountRoleService saasAccountRoleService;
    
    /**
     * 查询账号-角色关联信息
     */
    @ApiOperation(value = "查询账号-角色关联信息")
    @RequestMapping(value = "querySaasRoleMenuList")
    public ResponseResult querySaasRoleMenuList(@RequestBody @Validated SaasAccountRoleQueryVO queryVO) {
    	/*if (StringUtil.isBlank(queryVO.getAccountId()) && CollectionUtil.isEmpty(queryVO.getAccountIds())) {
			return ResponseResultUtil.errorResult(ResponseCode.A0402.getDesc(), "账号ID与账号ID集合参数必须存在其一");
		}*/
    	LambdaQueryWrapper<SaasAccountRole> queryWrapper = new SaasAccountRole.Builder().createQueryWrapper()
    			.accountIdEq(queryVO.getAccountId()).accountIdIn(queryVO.getAccountIds()).groupCodeEq(queryVO.getGroupCode())
    			.roleIdEq(queryVO.getRoleId()).roleIdIn(queryVO.getRoleIds()).builderQueryWrapper();
    	List<SaasAccountRole> list = this.saasAccountRoleService.list(queryWrapper);
    	if (CollectionUtil.isEmpty(list)) {
			return ResponseResultUtil.successResult(Lists.newArrayList(), 0L);
		}
        return ResponseResultUtil.successResult(list, (long)list.size());
    }
    
    /**
     * 新增
     */
	@ApiOperation(value = "新增账号-角色关联信息")
	@RequestMapping(value = "createSaasAccountRole")
    public ResponseResult createSaasAccountRole(@RequestBody @Validated SaasAccountRoleCreateVO createVO) {
		SaasAccountRole saasAccountRole = new SaasAccountRole();
		BeanUtils.copyProperties(createVO, saasAccountRole);
        boolean result = this.saasAccountRoleService.save(saasAccountRole);
        return result ? ResponseResultUtil.successResult("保存成功") : ResponseResultUtil.errorResult("保存失败");
    }
    
    /**
     * 删除新增
     */
	@ApiOperation(value = "删除新增账号-角色关联信息")
	@RequestMapping(value = "resetSaasAccountRole")
    public ResponseResult resetSaasAccountRole(@RequestBody @Validated SaasAccountRoleBatchVO batchVO) {
		boolean result = this.saasAccountRoleService.resetSaasAccountRole(batchVO.getGroupCode(), batchVO.getAccountId(), batchVO.getCasType(), batchVO.getRoles());
        return result ? ResponseResultUtil.successResult("重置成功") : ResponseResultUtil.errorResult("重置失败");
    }
	
    /**
     * 物理删除
     */
	@ApiOperation(value = "删除账号-角色关联信息")
	@RequestMapping(value = "deleteSaasAccountRole")
    public ResponseResult updateSaasAccountRole(@RequestBody @Validated SaasAccountRoleQueryVO deleteVO) {
		LambdaQueryWrapper<SaasAccountRole> queryWrapper = new SaasAccountRole.Builder().createQueryWrapper().accountIdEq(deleteVO.getAccountId())
				.groupCodeEq(deleteVO.getGroupCode()).roleIdEq(deleteVO.getRoleId()).casTypeEq(deleteVO.getCasType()).builderQueryWrapper();
        boolean result = this.saasAccountRoleService.remove(queryWrapper);
        return result ? ResponseResultUtil.successResult("删除成功") : ResponseResultUtil.errorResult("删除失败");
    }

}
