package com.persagy.account.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.google.common.collect.Lists;
import com.persagy.account.pojo.dto.SaasProductCategory;
import com.persagy.account.pojo.vo.product.SaasProductCategoryQueryVO;
import com.persagy.account.service.ISaasProductCategoryService;
import com.persagy.common.utils.ResponseResult;
import com.persagy.common.utils.ResponseResultUtil;

import cn.hutool.core.collection.CollectionUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 产品信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-05-11 19:23:03
 */

@Api(tags = "产品类别信息")
@RestController
@RequestMapping(value = "/productCategory", method = RequestMethod.POST)
public class SaasProductCategoryController {
	
    @Autowired
    private ISaasProductCategoryService SaasProductCategoryService;
    
    /**
     * 列表查询
     */
    @ApiOperation(value = "产品类别树查询")
    @RequestMapping(value = "querySaasProductCategoryTree")
    public ResponseResult querySaasProductCategoryTree(@RequestBody @Validated SaasProductCategoryQueryVO model) {
    	LambdaQueryWrapper<SaasProductCategory> queryWrapper = new SaasProductCategory.BuilderQueryWrapper()
    			.categoryNameLike(model.getCategoryName()).idEq(model.getId()).menuTypeEq(model.getMenuType())
    			.productTypeEq(model.getProductType()).terminalEq(model.getTerminal()).builder();
    	queryWrapper.apply("(PARENT_ID IS NULL OR TRIM(PARENT_ID) = '')");
    	List<SaasProductCategory> topList = this.SaasProductCategoryService.list(queryWrapper.orderByAsc(SaasProductCategory::getCreateTime));
    	if (CollectionUtil.isEmpty(topList)) {
			return ResponseResultUtil.successResult(Lists.newArrayList());
		}
    	this.querySaasProductCategoryTree(topList);
        return ResponseResultUtil.successResult(topList);
    }
    
    /**
     * 获取产品类别树
     * @param list
     */
    private void querySaasProductCategoryTree(List<SaasProductCategory> list) {
		for (SaasProductCategory categeory : list) {
			LambdaQueryWrapper<SaasProductCategory> queryWrapper = new SaasProductCategory.BuilderQueryWrapper().parentIdEq(categeory.getId()).builder();
	    	List<SaasProductCategory> nextList = this.SaasProductCategoryService.list(queryWrapper.orderByAsc(SaasProductCategory::getCreateTime));
	    	nextList = CollectionUtil.isEmpty(nextList) ? Lists.newArrayList() : nextList;
	    	categeory.setChildrens(nextList);
			this.querySaasProductCategoryTree(nextList);
		}
	}

    /**
     * 新增
     */
	@ApiOperation(value = "保存")
	@RequestMapping(value = "createSaasProductCategory")
    public ResponseResult createSaasProductCategory(@RequestBody SaasProductCategory SaasProductCategory) {
        boolean result = this.SaasProductCategoryService.save(SaasProductCategory);
        return result ? ResponseResultUtil.successResult("保存成功", SaasProductCategory.getId()) : ResponseResultUtil.errorResult("保存失败");
    }
    
    /**
     * 更新
     */
	@ApiOperation(value = "更新")
	@RequestMapping(value = "updateSaasProductCategory")
    public ResponseResult updateSaasProductCategory(@RequestBody SaasProductCategory SaasProductCategory) {
        boolean result = this.SaasProductCategoryService.updateById(SaasProductCategory);
        return result ? ResponseResultUtil.successResult("更新成功") : ResponseResultUtil.errorResult("更新失败");
    }

    /**
     * 物理删除
     */
    @ApiOperation(value = "删除")
    @RequestMapping(value = "deleteSaasProductCategory")
    public ResponseResult deleteSaasProductCategory(@RequestBody SaasProductCategory SaasProductCategory) {
        boolean result = this.SaasProductCategoryService.removeById(SaasProductCategory.getId());
        return result ? ResponseResultUtil.successResult("删除成功") : ResponseResultUtil.errorResult("删除失败");
    }
    
}
