package com.persagy.account.controller;

import java.util.List;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.google.common.collect.Lists;
import com.persagy.account.manage.SaasRoleMenuHandler;
import com.persagy.account.pojo.dto.SaasRoleMenu;
import com.persagy.account.pojo.vo.auth.SaasMenuFunctionVO;
import com.persagy.account.pojo.vo.auth.SaasRoleMenuBatchVO;
import com.persagy.account.pojo.vo.auth.SaasRoleMenuCreateVO;
import com.persagy.account.pojo.vo.auth.SaasRoleMenuQueryVO;
import com.persagy.account.service.ISaasRoleMenuService;
import com.persagy.common.utils.ResponseResult;
import com.persagy.common.utils.ResponseResultUtil;

import cn.hutool.core.collection.CollectionUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 角色-菜单功能关联信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */

@Api(tags = "角色-菜单功能关联信息")
@RestController
@RequestMapping(value = "/roleMenu", method = RequestMethod.POST)
public class SaasRoleMenuController {
	
    @Autowired
    private SaasRoleMenuHandler saasRoleMenuHandler;
    
    @Autowired
    private ISaasRoleMenuService saasRoleMenuService;
    
    /**
     * 查询角色-菜单功能关联信息
     */
    @ApiOperation(value = "查询角色-菜单功能关联信息")
    @RequestMapping(value = "querySaasRoleMenuList")
    public ResponseResult querySaasRoleMenuList(@RequestBody @Validated SaasRoleMenuQueryVO queryVO) {
    	LambdaQueryWrapper<SaasRoleMenu> queryWrapper = new SaasRoleMenu.Builder().createQueryWrapper()
    			.groupCodeEq(queryVO.getGroupCode()).roleIdEq(queryVO.getRoleId()).menuIdEq(queryVO.getMenuId())
    			.pageIdEq(queryVO.getPageId()).functionIdEq(queryVO.getFunctionId()).builderQueryWrapper();
    	List<SaasRoleMenu> list = this.saasRoleMenuService.list(queryWrapper);
    	if (CollectionUtil.isEmpty(list)) {
			return ResponseResultUtil.successResult(Lists.newArrayList(), 0L);
		}
        return ResponseResultUtil.successResult(list, (long)list.size());
    }

    /**
     * 新增
     */
	@ApiOperation(value = "保存")
	@RequestMapping(value = "createSaasRoleMenu")
    public ResponseResult createSaasRoleMenu(@RequestBody @Validated SaasRoleMenuCreateVO createVO) {
		SaasRoleMenu saasRoleMenu = new SaasRoleMenu();
		BeanUtils.copyProperties(createVO, saasRoleMenu);
        boolean result = this.saasRoleMenuService.save(saasRoleMenu);
        return result ? ResponseResultUtil.successResult("保存成功") : ResponseResultUtil.errorResult("保存失败");
    }
	
    /**
     * 先删后新增，删除此账号角色下的所有菜单功能点的关联关系，并重新新增
     */
	@ApiOperation(value = "删除新增")
	@RequestMapping(value = "resetSaasRoleMenu")
    public ResponseResult resetSaasRoleMenu(@RequestBody @Validated SaasRoleMenuBatchVO<SaasMenuFunctionVO> batchVO) {
		this.saasRoleMenuHandler.validRoleMenus(batchVO.getAuths());
		boolean result = this.saasRoleMenuHandler.resetSaasRoleMenu(batchVO.getGroupCode(), batchVO.getRoleId(), batchVO.getAuths());
        return result ? ResponseResultUtil.successResult("重置成功") : ResponseResultUtil.errorResult("重置失败");
    }
	
    /**
     * 物理删除
     */
    @ApiOperation(value = "删除")
    @RequestMapping(value = "deleteSaasRoleMenu")
    public ResponseResult deleteSaasRoleMenu(@RequestBody @Validated SaasRoleMenuQueryVO deleteVO) {
    	LambdaQueryWrapper<SaasRoleMenu> queryWrapper = new SaasRoleMenu.Builder().createQueryWrapper()
    			.groupCodeEq(deleteVO.getGroupCode()).roleIdEq(deleteVO.getRoleId()).menuIdEq(deleteVO.getMenuId())
    			.pageIdEq(deleteVO.getPageId()).functionIdEq(deleteVO.getFunctionId()).builderQueryWrapper();
        boolean result = this.saasRoleMenuService.remove(queryWrapper);
        return result ? ResponseResultUtil.successResult("删除成功") : ResponseResultUtil.errorResult("删除失败");
    }
    
}
