package com.persagy.account.manage;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.DataValidation;
import org.apache.poi.ss.usermodel.DataValidationConstraint;
import org.apache.poi.ss.usermodel.DataValidationHelper;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.apache.poi.xssf.usermodel.XSSFDataValidation;

import com.alibaba.excel.write.handler.SheetWriteHandler;
import com.alibaba.excel.write.metadata.holder.WriteSheetHolder;
import com.alibaba.excel.write.metadata.holder.WriteWorkbookHolder;
import com.google.common.collect.Lists;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.utils.ExcelUtil;
import com.persagy.common.utils.StringUtil;
import com.persagy.account.pojo.dto.SaasArea;
import com.persagy.account.pojo.dto.SaasGroup;
import com.persagy.account.pojo.vo.area.SaasAreaQueryVO;
import com.persagy.account.pojo.vo.group.SaasGroupQueryVO;

import cn.hutool.core.collection.CollectionUtil;

/**
 * 设置传感器模板文件下拉框选项值
 * 
 * @version v1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2020-11-25 19:52:37
 */
public class SaasProjectSheetWriteHandler implements SheetWriteHandler {

	private SaasAreaProjectHandler saasAreaProjectHandler;
	
	private SaasGroupProjectHandler saasGroupProjectHandler;
	
	private static String[] groupArray = null;
	
	// key-groupCode+groupName,value-目前是底层区域集合
	private Map<String, List<String>> areaMap = null;
	
	public SaasProjectSheetWriteHandler() {}
	
	public SaasProjectSheetWriteHandler(SaasGroupProjectHandler saasGroupProjectHandler, SaasAreaProjectHandler saasAreaProjectHandler) {
		this.saasAreaProjectHandler = saasAreaProjectHandler;
		this.saasGroupProjectHandler = saasGroupProjectHandler;
	}
	
	/**
	 * 再sheet创建之前，填充下拉框的数据
	 */
	@Override
	public void beforeSheetCreate(WriteWorkbookHolder writeWorkbookHolder, WriteSheetHolder writeSheetHolder) {
		// 1.查询集团项目
		SaasGroupQueryVO groupVO = new SaasGroupQueryVO();
		Map<String, String> temp = new HashMap<String, String>();
		List<SaasGroup> list = this.saasGroupProjectHandler.querySaasGroupList(groupVO);
		if (CollectionUtil.isNotEmpty(list)) {
			groupArray = new String[list.size()];
			for(int i = 0; i < list.size(); i++) {
				SaasGroup saasGroup = list.get(i);
				String value = saasGroup.getGroupCode() + "_" + saasGroup.getGroupName();
				temp.put(saasGroup.getGroupCode(), value);
				groupArray[i] = value;
			}
		} else {
			groupArray = new String[1];
			groupArray[0] = "";
		}
		// 2.查询集团区域信息
		SaasAreaQueryVO queryVO = new SaasAreaQueryVO();
		queryVO.setAreaType(SaasCommonConstant.STR_STATUS_1);		//1-底层区域
		List<SaasArea> areaList = this.saasAreaProjectHandler.querySaasAreaList(queryVO, true);
		if (CollectionUtil.isNotEmpty(areaList)) {
			areaMap = new HashMap<String, List<String>>();
			for (SaasArea saasArea : areaList) {
				String groupCode = saasArea.getGroupCode();
				String key = temp.get(groupCode);
				if (StringUtil.isNotBlank(key)) {
					if (areaMap.containsKey(key)) {
						areaMap.get(key).add(saasArea.getAreaName());
					} else {
						areaMap.put(key, Lists.newArrayList(saasArea.getAreaName()));
					}
				}
			}
		}
	}

	/**
	 * 设置单个下拉框
	 */
	@Override
	public void afterSheetCreate(WriteWorkbookHolder writeWorkbookHolder, WriteSheetHolder writeSheetHolder) {
		// 1.设置集团下拉框
		Sheet sheet = writeSheetHolder.getSheet();
		DataValidationHelper helper = sheet.getDataValidationHelper();
		CellRangeAddressList cellRangeAddressList = new CellRangeAddressList(1, 500, 1, 1);
		DataValidationConstraint constraint = helper.createExplicitListConstraint(groupArray);
		DataValidation dataValidation = helper.createValidation(constraint, cellRangeAddressList);
		// 阻止输入非下拉选项的值
		dataValidation.setErrorStyle(DataValidation.ErrorStyle.STOP);
		// 处理Excel兼容性问题
		if (dataValidation instanceof XSSFDataValidation) {
			dataValidation.setSuppressDropDownArrow(true);
			dataValidation.setShowErrorBox(true);
		} else {
			dataValidation.setSuppressDropDownArrow(false);
		}
		sheet.addValidationData(dataValidation);
		
		// 设置级联下拉框
		if (areaMap != null) {
			Workbook workbook = writeWorkbookHolder.getWorkbook();
			Sheet hideSheet = workbook.getSheet("area");
			if (hideSheet == null) {
				hideSheet = workbook.createSheet("area");
				// 这一行作用是将此sheet隐藏，功能未完成时注释此行,可以查看隐藏sheet中信息是否正确
				workbook.setSheetHidden(workbook.getSheetIndex(hideSheet), true);
				// 设置第一行，存集团信息
				int rowId = 0;
		        Iterator<String> keyIterator = areaMap.keySet().iterator();
				while (keyIterator.hasNext()) {
					String key = keyIterator.next();			// 集团编码
					List<String> son = areaMap.get(key);		// 集团下底层分区
					Row row = hideSheet.createRow(rowId++);		// 集团下底层分区所在行
					row.createCell(0).setCellValue(key);		// 第一列为父名称，即集团编码
					
					for (int i = 0; i < son.size(); i++) {		// 此行依次填充底层分区信息
						Cell cell = row.createCell(i + 1);
						cell.setCellValue(son.get(i));			
					}
					
					// 添加名称管理器 从第几列、第几行开始引用 ，总共多少列
					String range = ExcelUtil.getRange(1, rowId, son.size());	
					Name name = workbook.createName();
					name.setNameName(key);
					String formula = "area!" + range;
					name.setRefersToFormula(formula);
				}
			}
			
			// 这是级联下拉实现
			CellRangeAddressList areaCellRangeAddressList = new CellRangeAddressList(1, 500, 2, 2);
			DataValidationConstraint areaConstraint = helper.createFormulaListConstraint("INDIRECT($B" + 2 + ")");
	        DataValidation areaValidation = helper.createValidation(areaConstraint, areaCellRangeAddressList);
	        // 阻止输入非下拉选项的值
	        areaValidation.setErrorStyle(DataValidation.ErrorStyle.STOP);
	 		// 处理Excel兼容性问题
	 		if (areaValidation instanceof XSSFDataValidation) {
	 			areaValidation.setSuppressDropDownArrow(true);
	 			areaValidation.setShowErrorBox(true);
	 		} else {
	 			areaValidation.setSuppressDropDownArrow(false);
	 		}
	        sheet.addValidationData(areaValidation);
		}
	}

}
