package com.persagy.account.pojo.dto;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.persagy.common.utils.StringUtil;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 集团信息
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("saas_group")
public class SaasGroup extends Model<SaasGroup> {
	private static final long serialVersionUID = -8224369302252013334L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupCode; // 集团编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupName; // 集团名称,业务保证唯一性

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupIcon; // 集团图标

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupDesc; // 集团描述

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String deployModel; // 集团部署方式，0-公有云，1-私有云

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String syncState; // 数据同步状态,0-数据同步失败，1-数据同步成功

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date syncTime; // 上次数据同步时间

	@TableField(fill = FieldFill.INSERT, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date createTime; // 创建时间

	@TableField(fill = FieldFill.INSERT_UPDATE, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date updateTime; // 更新时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String updateUser; // 最后一次操作者ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String remark; // 备注

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Integer valid; // 0-不可用，1-可用

	@TableField(exist = false)
	private List<SaasProject> projects;		//项目集合
	
	@TableField(exist = false)
	private List<SaasArea> areas;	//集团下顶层区域
	
	@TableField(exist = false)
	private String type;	//类型 create-创建，update-更新
	
	public static class Builder {

		private LambdaQueryWrapper<SaasGroup> queryWrapper = null;

		private LambdaUpdateWrapper<SaasGroup> updateWrapper = null;

		public Builder createQueryWrapper() {
			queryWrapper = new LambdaQueryWrapper<SaasGroup>();
			return this;
		}

		public Builder createUpdateWrapper() {
			updateWrapper = new LambdaUpdateWrapper<SaasGroup>();
			return this;
		}

		public Builder groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getGroupCode, groupCode);
				} else {
					queryWrapper.eq(SaasGroup::getGroupCode, groupCode);
				}
			}
			return this;
		}

		public Builder groupNameEq(String groupName) {
			if (StringUtil.isNotBlank(groupName)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getGroupName, groupName);
				} else {
					queryWrapper.eq(SaasGroup::getGroupName, groupName);
				}
			}
			return this;
		}
		
		public Builder groupNameLike(String groupName) {
			if (StringUtil.isNotBlank(groupName)) {
				if (updateWrapper != null) {
					updateWrapper.like(SaasGroup::getGroupName, groupName);
				} else {
					queryWrapper.like(SaasGroup::getGroupName, groupName);
				}
			}
			return this;
		}

		public Builder groupIconEq(String groupIcon) {
			if (StringUtil.isNotBlank(groupIcon)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getGroupIcon, groupIcon);
				} else {
					queryWrapper.eq(SaasGroup::getGroupIcon, groupIcon);
				}
			}
			return this;
		}

		public Builder groupDescEq(String groupDesc) {
			if (StringUtil.isNotBlank(groupDesc)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getGroupDesc, groupDesc);
				} else {
					queryWrapper.eq(SaasGroup::getGroupDesc, groupDesc);
				}
			}
			return this;
		}

		public Builder deployModelEq(String deployModel) {
			if (StringUtil.isNotBlank(deployModel)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getDeployModel, deployModel);
				} else {
					queryWrapper.eq(SaasGroup::getDeployModel, deployModel);
				}
			}
			return this;
		}

		public Builder syncStateEq(String syncState) {
			if (StringUtil.isNotBlank(syncState)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getSyncState, syncState);
				} else {
					queryWrapper.eq(SaasGroup::getSyncState, syncState);
				}
			}
			return this;
		}

		public Builder syncTimeEq(Date syncTime) {
			if (null != syncTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getSyncTime, syncTime);
				} else {
					queryWrapper.eq(SaasGroup::getSyncTime, syncTime);
				}
			}
			return this;
		}

		public Builder createTimeEq(Date createTime) {
			if (null != createTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getCreateTime, createTime);
				} else {
					queryWrapper.eq(SaasGroup::getCreateTime, createTime);
				}
			}
			return this;
		}

		public Builder updateTimeEq(Date updateTime) {
			if (null != updateTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getUpdateTime, updateTime);
				} else {
					queryWrapper.eq(SaasGroup::getUpdateTime, updateTime);
				}
			}
			return this;
		}

		public Builder updateUserEq(String updateUser) {
			if (StringUtil.isNotBlank(updateUser)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getUpdateUser, updateUser);
				} else {
					queryWrapper.eq(SaasGroup::getUpdateUser, updateUser);
				}
			}
			return this;
		}

		public Builder remarkEq(String remark) {
			if (StringUtil.isNotBlank(remark)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getRemark, remark);
				} else {
					queryWrapper.eq(SaasGroup::getRemark, remark);
				}
			}
			return this;
		}

		public Builder validEq(Integer valid) {
			if (null != valid) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasGroup::getValid, valid);
				} else {
					queryWrapper.eq(SaasGroup::getValid, valid);
				}
			}
			return this;
		}

		public LambdaQueryWrapper<SaasGroup> builderQueryWrapper() {
			return queryWrapper;
		}

		public LambdaUpdateWrapper<SaasGroup> builderUpdateWrapper() {
			return updateWrapper;
		}
	}
}
