package com.persagy.account.pojo.dto;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.persagy.common.utils.StringUtil;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 项目签约产品
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-05-07 12:02:40
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("saas_project_product")
public class SaasProjectProduct extends Model<SaasProjectProduct> {
	private static final long serialVersionUID = 4396612247398410758L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String contractId; // 集团签约ID
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupCode; // 集团编码
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String projectId; // 产品ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String productId; // 产品ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date productContract; // 签约时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String remark; // 备注
	
	@TableField(exist = false)
	private String projectName; // 项目名称

	public static class BuilderQueryWrapper {

		private LambdaQueryWrapper<SaasProjectProduct> queryWrapper = new LambdaQueryWrapper<SaasProjectProduct>();

		public BuilderQueryWrapper contractIdEq(String contractId) {
			if (StringUtil.isNotBlank(contractId)) {
				queryWrapper.eq(SaasProjectProduct::getContractId, contractId);
			}
			return this;
		}
		
		public BuilderQueryWrapper groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				queryWrapper.eq(SaasProjectProduct::getGroupCode, groupCode);
			}
			return this;
		}
		
		public BuilderQueryWrapper projectIdEq(String projectId) {
			if (StringUtil.isNotBlank(projectId)) {
				queryWrapper.eq(SaasProjectProduct::getProjectId, projectId);
			}
			return this;
		}

		public BuilderQueryWrapper productIdEq(String productId) {
			if (StringUtil.isNotBlank(productId)) {
				queryWrapper.eq(SaasProjectProduct::getProductId, productId);
			}
			return this;
		}

		public BuilderQueryWrapper productContractEq(Date productContract) {
			if (null != productContract) {
				queryWrapper.eq(SaasProjectProduct::getProductContract, productContract);
			}
			return this;
		}

		public BuilderQueryWrapper remarkEq(String remark) {
			if (StringUtil.isNotBlank(remark)) {
				queryWrapper.eq(SaasProjectProduct::getRemark, remark);
			}
			return this;
		}

		public LambdaQueryWrapper<SaasProjectProduct> builder() {
			return queryWrapper;
		}

	}

	public static class BuilderUpdateWrapper {

		private LambdaUpdateWrapper<SaasProjectProduct> updateWrapper = new LambdaUpdateWrapper<SaasProjectProduct>();

		public BuilderUpdateWrapper contractIdEq(String contractId) {
			if (StringUtil.isNotBlank(contractId)) {
				updateWrapper.eq(SaasProjectProduct::getContractId, contractId);
			}
			return this;
		}
		
		public BuilderUpdateWrapper groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				updateWrapper.eq(SaasProjectProduct::getGroupCode, groupCode);
			}
			return this;
		}
		
		public BuilderUpdateWrapper projectIdEq(String projectId) {
			if (StringUtil.isNotBlank(projectId)) {
				updateWrapper.eq(SaasProjectProduct::getProjectId, projectId);
			}
			return this;
		}

		public BuilderUpdateWrapper productIdEq(String productId) {
			if (StringUtil.isNotBlank(productId)) {
				updateWrapper.eq(SaasProjectProduct::getProductId, productId);
			}
			return this;
		}

		public BuilderUpdateWrapper productContractEq(Date productContract) {
			if (null != productContract) {
				updateWrapper.eq(SaasProjectProduct::getProductContract, productContract);
			}
			return this;
		}

		public BuilderUpdateWrapper remarkEq(String remark) {
			if (StringUtil.isNotBlank(remark)) {
				updateWrapper.eq(SaasProjectProduct::getRemark, remark);
			}
			return this;
		}

		public LambdaUpdateWrapper<SaasProjectProduct> builder() {
			return updateWrapper;
		}

	}
}
