package com.persagy.account.pojo.dto;

import java.util.Date;
import java.util.Set;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.persagy.common.annotation.IdGeneratorPrefix;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.model.BaseEntity;
import com.persagy.common.utils.StringUtil;

import cn.hutool.core.collection.CollectionUtil;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 角色信息
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("saas_role")
@IdGeneratorPrefix(SaasCommonConstant.SAAS_ROLE_ID_PREFIX)
public class SaasRole extends BaseEntity<SaasRole> {
	private static final long serialVersionUID = 7817018825667753153L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String groupCode; // 集团编码
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String roleCode; // 角色编码

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String roleName; // 角色名称

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String roleType; // 角色类型，0-系统角色，1-业务角色, 2-业务超管默认角色
	
	@TableField(fill = FieldFill.INSERT, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date createTime; // 创建时间

	@TableField(fill = FieldFill.INSERT_UPDATE, updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date updateTime; // 更新时间

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String updateUser; // 最后一次操作者ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String remark; // 备注

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Integer valid; // 0-不可用，1-可用
	
	@TableField(exist = false)
	private Integer countMenu;	//统计出菜单数量
	
	@TableField(exist = false)
	private Integer countFunction;	//统计出下级功能点数量

	public static class Builder {

		private LambdaQueryWrapper<SaasRole> queryWrapper = null;

		private LambdaUpdateWrapper<SaasRole> updateWrapper = null;

		public Builder createQueryWrapper() {
			queryWrapper = new LambdaQueryWrapper<SaasRole>();
			return this;
		}

		public Builder createUpdateWrapper() {
			updateWrapper = new LambdaUpdateWrapper<SaasRole>();
			return this;
		}

		public Builder idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getId, id);
				} else {
					queryWrapper.eq(SaasRole::getId, id);
				}
			}
			return this;
		}
		
		public Builder idIn(Set<String> ids) {
			if (CollectionUtil.isNotEmpty(ids)) {
				if (updateWrapper != null) {
					updateWrapper.in(SaasRole::getId, ids);
				} else {
					queryWrapper.in(SaasRole::getId, ids);
				}
			}
			return this;
		}

		public Builder groupCodeEq(String groupCode) {
			if (StringUtil.isNotBlank(groupCode)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getGroupCode, groupCode);
				} else {
					queryWrapper.eq(SaasRole::getGroupCode, groupCode);
				}
			}
			return this;
		}
		
		public Builder roleCodeEq(String roleCode) {
			if (StringUtil.isNotBlank(roleCode)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getRoleCode, roleCode);
				} else {
					queryWrapper.eq(SaasRole::getRoleCode, roleCode);
				}
			}
			return this;
		}

		public Builder roleNameEq(String roleName) {
			if (StringUtil.isNotBlank(roleName)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getRoleName, roleName);
				} else {
					queryWrapper.eq(SaasRole::getRoleName, roleName);
				}
			}
			return this;
		}
		
		public Builder roleNameLike(String roleName) {
			if (StringUtil.isNotBlank(roleName)) {
				if (updateWrapper != null) {
					updateWrapper.like(SaasRole::getRoleName, roleName);
				} else {
					queryWrapper.like(SaasRole::getRoleName, roleName);
				}
			}
			return this;
		}
		
		public Builder roleTypeEq(String roleType) {
			if (StringUtil.isNotBlank(roleType)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getRoleType, roleType);
				} else {
					queryWrapper.eq(SaasRole::getRoleType, roleType);
				}
			}
			return this;
		}
		
		public Builder roleTypeIn(Set<String> roleTypes) {
			if (CollectionUtil.isNotEmpty(roleTypes)) {
				if (updateWrapper != null) {
					updateWrapper.in(SaasRole::getRoleType, roleTypes);
				} else {
					queryWrapper.in(SaasRole::getRoleType, roleTypes);
				}
			}
			return this;
		}

		public Builder createTimeEq(Date createTime) {
			if (null != createTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getCreateTime, createTime);
				} else {
					queryWrapper.eq(SaasRole::getCreateTime, createTime);
				}
			}
			return this;
		}

		public Builder updateTimeEq(Date updateTime) {
			if (null != updateTime) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getUpdateTime, updateTime);
				} else {
					queryWrapper.eq(SaasRole::getUpdateTime, updateTime);
				}
			}
			return this;
		}

		public Builder updateUserEq(String updateUser) {
			if (StringUtil.isNotBlank(updateUser)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getUpdateUser, updateUser);
				} else {
					queryWrapper.eq(SaasRole::getUpdateUser, updateUser);
				}
			}
			return this;
		}

		public Builder remarkEq(String remark) {
			if (StringUtil.isNotBlank(remark)) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getRemark, remark);
				} else {
					queryWrapper.eq(SaasRole::getRemark, remark);
				}
			}
			return this;
		}

		public Builder validEq(Integer valid) {
			if (null != valid) {
				if (updateWrapper != null) {
					updateWrapper.eq(SaasRole::getValid, valid);
				} else {
					queryWrapper.eq(SaasRole::getValid, valid);
				}
			}
			return this;
		}

		public LambdaQueryWrapper<SaasRole> builderQueryWrapper() {
			return queryWrapper;
		}

		public LambdaUpdateWrapper<SaasRole> builderUpdateWrapper() {
			return updateWrapper;
		}
	}
}
