package com.persagy.account.pojo.vo.role;

import java.util.List;

import javax.validation.constraints.NotBlank;

import com.persagy.common.model.BaseUserModel;
import com.persagy.account.pojo.vo.auth.SaasMenuFunctionVO;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 角色信息
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Getter
@Setter
@ApiModel
@ToString
public class SaasRoleCreateVO extends BaseUserModel {

	@ApiModelProperty(value = "集团编码，作为SQL条件", required = true, example = "RC")
	private String groupCode; 	// 所属集团编码
	
	@ApiModelProperty(value = "角色ID，更新时不可为空", example = "1001")
	private String id; 			// 角色ID
	
	@ApiModelProperty(value = "角色编码", example = "zhangsan")
	private String roleCode; 	// 角色编码
	
	@NotBlank(message = "角色名称，不可为空")
	@ApiModelProperty(value = "角色名称", example = "zhangsan")
	private String roleName; 	// 角色名称
	
	@NotBlank(message = "角色类型不可为空")
	@ApiModelProperty(value = "角色类型，0-系统角色，1-业务角色, 2-业务超管默认角色", example = "zhangsan")
	private String roleType; // 角色类型，0-系统角色，1-业务角色, 2-业务超管默认角色

	@ApiModelProperty(value = "菜单功能权限集合", example = "[{menuId:123, functionId:456}]")
	private List<SaasMenuFunctionVO> auths; 	// 菜单功能权限集合
	
	@ApiModelProperty(value = "备注信息", example = "测试角色")
	private String remark; 		// 备注
	
}
