package com.persagy.account.service.impl;

import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.exception.BusinessException;
import com.persagy.common.service.impl.SuperServiceImpl;
import com.persagy.common.utils.StringUtil;
import com.persagy.account.config.ApplicationProperties;
import com.persagy.account.mapper.SaasRoleMapper;
import com.persagy.account.mapper.SaasRoleMenuMapper;
import com.persagy.account.pojo.dto.SaasRole;
import com.persagy.account.pojo.dto.SaasRoleMenu;
import com.persagy.account.service.ISaasRoleService;

import cn.hutool.core.collection.CollectionUtil;

/**
 * 角色信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
@Service
public class SaasRoleServiceImpl extends SuperServiceImpl<SaasRoleMapper, SaasRole> implements ISaasRoleService {

	@Autowired
	private ApplicationProperties properties;
	
	@Autowired
	private SaasRoleMenuMapper saasRoleMenuMapper;
	
	@Override
	public SaasRole getOne(String id) {
		LambdaQueryWrapper<SaasRole> queryWrapper = new SaasRole.Builder().createQueryWrapper().idEq(id).validEq(SaasCommonConstant.STATUS_1).builderQueryWrapper();
		return this.baseMapper.selectOne(queryWrapper);
	}
	
	@Override
	public List<SaasRole> querySaasRoleList(String accountId) {
		return this.baseMapper.querySaasRoleList(accountId, SaasCommonConstant.STATUS_1);
	}

	@Override
	public boolean validRoleName(String groupCode, String roleName, String roleType, String roleId) {
		LambdaQueryWrapper<SaasRole> queryWrapper = new SaasRole.Builder().createQueryWrapper().groupCodeEq(groupCode)
				.roleNameEq(roleName).roleTypeEq(roleType).validEq(SaasCommonConstant.STATUS_1).builderQueryWrapper();
		List<SaasRole> list = this.baseMapper.selectList(queryWrapper);
		if (CollectionUtil.isEmpty(list)) {
			return true;
		}
		if (StringUtil.isNotBlank(roleId) && list.size() == 1 && roleId.equals(list.get(0).getId())) {
			return true;
		}
		return false;
	}

	@Override
	@Transactional
	public boolean createDefaultRole(String groupCode, String updateUser) {
		Date date = new Date();
		SaasRole saasRole = new SaasRole();
		saasRole.setGroupCode(groupCode);
		saasRole.setRoleCode("1001");
		saasRole.setRoleName("超级管理员");
		saasRole.setRoleType(SaasCommonConstant.STR_STATUS_2);
		saasRole.setRemark("自动创建默认业务超管角色");
		saasRole.setCreateTime(date);
		saasRole.setUpdateTime(date);
		saasRole.setUpdateUser(updateUser);
		int result = this.baseMapper.insert(saasRole);
		if (result < 1) {
			throw new BusinessException("业务超管默认角色添加失败");
		}
		// 插入菜单与该角色的关联关系
		SaasRoleMenu saasRoleMenu = new SaasRoleMenu();
		saasRoleMenu.setGroupCode(groupCode);
		saasRoleMenu.setRoleId(saasRole.getId());
		saasRoleMenu.setMenuId(properties.getDefaultMenuId());
		saasRoleMenu.setFunctionId(properties.getDefaultFunId());
		result = this.saasRoleMenuMapper.insert(saasRoleMenu);
		return SqlHelper.retBool(result);
	}

}
